@@ -1,14 +1,14 @@
 
 import asyncio
 from concurrent.futures import ProcessPoolExecutor
-from typing import Any, Awaitable, Coroutine, Dict, Iterable
+from typing import Any, Awaitable, Callable, Coroutine, Dict, Iterable
 
 import eth_retry
 from web3 import AsyncHTTPProvider, Web3
 from web3.eth import AsyncEth
 from web3.providers.async_base import AsyncBaseProvider
 
-from multicall.constants import AIOHTTP_TIMEOUT, Network
+from multicall.constants import AIOHTTP_TIMEOUT, NUM_PROCESSES, Network
 
 chainids: Dict[Web3,int] = {}
 
@@ -24,7 +24,7 @@ def chain_id(w3: Web3) -> int:
         return chainids[w3]
 
 async_w3s: Dict[Web3,Web3] = {}
-process_pool_executor = ProcessPoolExecutor(16)
+process_pool_executor = ProcessPoolExecutor(NUM_PROCESSES)
 
 def get_endpoint(w3: Web3) -> str:
     provider = w3.provider
@@ -59,15 +59,15 @@ def get_event_loop() -> asyncio.AbstractEventLoop:
     except RuntimeError as e: # Necessary for use with multi-threaded applications.
         if not str(e).startswith("There is no current event loop in thread"):
             raise e
-        loop = asyncio.new_event_loop()
-        #asyncio.set_event_loop(loop)
-        return loop
+        return asyncio.new_event_loop()
 
 def await_awaitable(awaitable: Awaitable) -> Any:
     return get_event_loop().run_until_complete(awaitable)
 
-async def run_in_subprocess(coro: Coroutine, *args: Any, **kwargs) -> Any:
-    return await asyncio.get_event_loop().run_in_executor(process_pool_executor, coro, *args, **kwargs)
+async def run_in_subprocess(callable: Callable, *args: Any, **kwargs) -> Any:
+    if NUM_PROCESSES == 1:
+        return callable(*args, **kwargs)
+    return await asyncio.get_event_loop().run_in_executor(process_pool_executor, callable, *args, **kwargs)
 
 def raise_if_exception(obj: Any) -> None:
     if isinstance(obj, Exception):
